@@ -33,7 +33,7 @@ class Html_bootstrap:
 
     def load_html_templates(self):
 
-        files =listdir(HTML_TEMPLATE_PATH)
+        files = pkg_resources.resource_listdir(__name__, HTML_TEMPLATE_PATH)
 
         # load html templates into memory
         for i in files:
@@ -41,8 +41,8 @@ class Html_bootstrap:
             filename = HTML_TEMPLATE_PATH + '/' + i
             
         
-            stream = pkg_resources.resource_stream(__name__, filename)
-            html_templates[item] = stream.read()
+            html_templates[item] = pkg_resources.resource_string(__name__, filename)
+            html_templates[item] = html_templates[item].decode("utf-8")
         return
 
 
