@@ -264,9 +264,10 @@ class Kraken_html:
         filename = CONTENT_TEMPLATE + page + '_' + language + '.json'
 
         # Load file
-        stream = pkg_resources.resource_stream(__name__, filename)
 
-        content = stream.read()
+        content = pkg_resources.resource_string(__name__, filename)
+        content = content.decode("utf-8")
+        
 
         # COnvert \n to <br>
         content = content.replace('\\n', '<br>')
